# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class RiskV1AddressVerificationsPost201Response(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'links': 'PtsV2IncrementalAuthorizationPatch201ResponseLinks',
        'id': 'str',
        'submit_time_utc': 'str',
        'submit_time_local': 'str',
        'status': 'str',
        'message': 'str',
        'client_reference_information': 'PtsV2IncrementalAuthorizationPatch201ResponseClientReferenceInformation',
        'address_verification_information': 'RiskV1AddressVerificationsPost201ResponseAddressVerificationInformation',
        'error_information': 'RiskV1AddressVerificationsPost201ResponseErrorInformation'
    }

    attribute_map = {
        'links': '_links',
        'id': 'id',
        'submit_time_utc': 'submitTimeUtc',
        'submit_time_local': 'submitTimeLocal',
        'status': 'status',
        'message': 'message',
        'client_reference_information': 'clientReferenceInformation',
        'address_verification_information': 'addressVerificationInformation',
        'error_information': 'errorInformation'
    }

    def __init__(self, links=None, id=None, submit_time_utc=None, submit_time_local=None, status=None, message=None, client_reference_information=None, address_verification_information=None, error_information=None):
        """
        RiskV1AddressVerificationsPost201Response - a model defined in Swagger
        """

        self._links = None
        self._id = None
        self._submit_time_utc = None
        self._submit_time_local = None
        self._status = None
        self._message = None
        self._client_reference_information = None
        self._address_verification_information = None
        self._error_information = None

        if links is not None:
          self.links = links
        if id is not None:
          self.id = id
        if submit_time_utc is not None:
          self.submit_time_utc = submit_time_utc
        if submit_time_local is not None:
          self.submit_time_local = submit_time_local
        if status is not None:
          self.status = status
        if message is not None:
          self.message = message
        if client_reference_information is not None:
          self.client_reference_information = client_reference_information
        if address_verification_information is not None:
          self.address_verification_information = address_verification_information
        if error_information is not None:
          self.error_information = error_information

    @property
    def links(self):
        """
        Gets the links of this RiskV1AddressVerificationsPost201Response.

        :return: The links of this RiskV1AddressVerificationsPost201Response.
        :rtype: PtsV2IncrementalAuthorizationPatch201ResponseLinks
        """
        return self._links

    @links.setter
    def links(self, links):
        """
        Sets the links of this RiskV1AddressVerificationsPost201Response.

        :param links: The links of this RiskV1AddressVerificationsPost201Response.
        :type: PtsV2IncrementalAuthorizationPatch201ResponseLinks
        """

        self._links = links

    @property
    def id(self):
        """
        Gets the id of this RiskV1AddressVerificationsPost201Response.
        An unique identification number to identify the submitted request. It is also appended to the endpoint of the resource.  On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.  #### PIN debit Returned for all PIN debit services. 

        :return: The id of this RiskV1AddressVerificationsPost201Response.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this RiskV1AddressVerificationsPost201Response.
        An unique identification number to identify the submitted request. It is also appended to the endpoint of the resource.  On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.  #### PIN debit Returned for all PIN debit services. 

        :param id: The id of this RiskV1AddressVerificationsPost201Response.
        :type: str
        """
        if id is not None and len(id) > 26:
            raise ValueError("Invalid value for `id`, length must be less than or equal to `26`")

        self._id = id

    @property
    def submit_time_utc(self):
        """
        Gets the submit_time_utc of this RiskV1AddressVerificationsPost201Response.
        Time of request in UTC. Format: `YYYY-MM-DDThh:mm:ssZ` **Example** `2016-08-11T22:47:57Z` equals August 11, 2016, at 22:47:57 (10:47:57 p.m.). The `T` separates the date and the time. The `Z` indicates UTC.  Returned by authorization service.  #### PIN debit Time when the PIN debit credit, PIN debit purchase or PIN debit reversal was requested.  Returned by PIN debit credit, PIN debit purchase or PIN debit reversal. 

        :return: The submit_time_utc of this RiskV1AddressVerificationsPost201Response.
        :rtype: str
        """
        return self._submit_time_utc

    @submit_time_utc.setter
    def submit_time_utc(self, submit_time_utc):
        """
        Sets the submit_time_utc of this RiskV1AddressVerificationsPost201Response.
        Time of request in UTC. Format: `YYYY-MM-DDThh:mm:ssZ` **Example** `2016-08-11T22:47:57Z` equals August 11, 2016, at 22:47:57 (10:47:57 p.m.). The `T` separates the date and the time. The `Z` indicates UTC.  Returned by authorization service.  #### PIN debit Time when the PIN debit credit, PIN debit purchase or PIN debit reversal was requested.  Returned by PIN debit credit, PIN debit purchase or PIN debit reversal. 

        :param submit_time_utc: The submit_time_utc of this RiskV1AddressVerificationsPost201Response.
        :type: str
        """

        self._submit_time_utc = submit_time_utc

    @property
    def submit_time_local(self):
        """
        Gets the submit_time_local of this RiskV1AddressVerificationsPost201Response.
        Time that the transaction was submitted in local time.

        :return: The submit_time_local of this RiskV1AddressVerificationsPost201Response.
        :rtype: str
        """
        return self._submit_time_local

    @submit_time_local.setter
    def submit_time_local(self, submit_time_local):
        """
        Sets the submit_time_local of this RiskV1AddressVerificationsPost201Response.
        Time that the transaction was submitted in local time.

        :param submit_time_local: The submit_time_local of this RiskV1AddressVerificationsPost201Response.
        :type: str
        """

        self._submit_time_local = submit_time_local

    @property
    def status(self):
        """
        Gets the status of this RiskV1AddressVerificationsPost201Response.
        The status for the call can be: - COMPLETED - INVALID_REQUEST - DECLINED 

        :return: The status of this RiskV1AddressVerificationsPost201Response.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this RiskV1AddressVerificationsPost201Response.
        The status for the call can be: - COMPLETED - INVALID_REQUEST - DECLINED 

        :param status: The status of this RiskV1AddressVerificationsPost201Response.
        :type: str
        """

        self._status = status

    @property
    def message(self):
        """
        Gets the message of this RiskV1AddressVerificationsPost201Response.
        The message describing the reason of the status. Value can be   - Apartment number missing or not found.   - Insufficient address information.   - House/Box number not found on street.   - Multiple address matches were found.   - P.O. Box identifier not found or out of range.   - Route service identifier not found or out of range.   - Street name not found in Postal code.   - Postal code not found in database.   - Unable to verify or correct address.   - Multiple addres matches were found (international)   - Address match not found (no reason given)   - Unsupported character set 

        :return: The message of this RiskV1AddressVerificationsPost201Response.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """
        Sets the message of this RiskV1AddressVerificationsPost201Response.
        The message describing the reason of the status. Value can be   - Apartment number missing or not found.   - Insufficient address information.   - House/Box number not found on street.   - Multiple address matches were found.   - P.O. Box identifier not found or out of range.   - Route service identifier not found or out of range.   - Street name not found in Postal code.   - Postal code not found in database.   - Unable to verify or correct address.   - Multiple addres matches were found (international)   - Address match not found (no reason given)   - Unsupported character set 

        :param message: The message of this RiskV1AddressVerificationsPost201Response.
        :type: str
        """

        self._message = message

    @property
    def client_reference_information(self):
        """
        Gets the client_reference_information of this RiskV1AddressVerificationsPost201Response.

        :return: The client_reference_information of this RiskV1AddressVerificationsPost201Response.
        :rtype: PtsV2IncrementalAuthorizationPatch201ResponseClientReferenceInformation
        """
        return self._client_reference_information

    @client_reference_information.setter
    def client_reference_information(self, client_reference_information):
        """
        Sets the client_reference_information of this RiskV1AddressVerificationsPost201Response.

        :param client_reference_information: The client_reference_information of this RiskV1AddressVerificationsPost201Response.
        :type: PtsV2IncrementalAuthorizationPatch201ResponseClientReferenceInformation
        """

        self._client_reference_information = client_reference_information

    @property
    def address_verification_information(self):
        """
        Gets the address_verification_information of this RiskV1AddressVerificationsPost201Response.

        :return: The address_verification_information of this RiskV1AddressVerificationsPost201Response.
        :rtype: RiskV1AddressVerificationsPost201ResponseAddressVerificationInformation
        """
        return self._address_verification_information

    @address_verification_information.setter
    def address_verification_information(self, address_verification_information):
        """
        Sets the address_verification_information of this RiskV1AddressVerificationsPost201Response.

        :param address_verification_information: The address_verification_information of this RiskV1AddressVerificationsPost201Response.
        :type: RiskV1AddressVerificationsPost201ResponseAddressVerificationInformation
        """

        self._address_verification_information = address_verification_information

    @property
    def error_information(self):
        """
        Gets the error_information of this RiskV1AddressVerificationsPost201Response.

        :return: The error_information of this RiskV1AddressVerificationsPost201Response.
        :rtype: RiskV1AddressVerificationsPost201ResponseErrorInformation
        """
        return self._error_information

    @error_information.setter
    def error_information(self, error_information):
        """
        Sets the error_information of this RiskV1AddressVerificationsPost201Response.

        :param error_information: The error_information of this RiskV1AddressVerificationsPost201Response.
        :type: RiskV1AddressVerificationsPost201ResponseErrorInformation
        """

        self._error_information = error_information

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, RiskV1AddressVerificationsPost201Response):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
