# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class VerifyCustomerAddressRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'client_reference_information': 'Riskv1addressverificationsClientReferenceInformation',
        'order_information': 'Riskv1addressverificationsOrderInformation',
        'buyer_information': 'Riskv1addressverificationsBuyerInformation'
    }

    attribute_map = {
        'client_reference_information': 'clientReferenceInformation',
        'order_information': 'orderInformation',
        'buyer_information': 'buyerInformation'
    }

    def __init__(self, client_reference_information=None, order_information=None, buyer_information=None):
        """
        VerifyCustomerAddressRequest - a model defined in Swagger
        """

        self._client_reference_information = None
        self._order_information = None
        self._buyer_information = None

        if client_reference_information is not None:
          self.client_reference_information = client_reference_information
        if order_information is not None:
          self.order_information = order_information
        if buyer_information is not None:
          self.buyer_information = buyer_information

    @property
    def client_reference_information(self):
        """
        Gets the client_reference_information of this VerifyCustomerAddressRequest.

        :return: The client_reference_information of this VerifyCustomerAddressRequest.
        :rtype: Riskv1addressverificationsClientReferenceInformation
        """
        return self._client_reference_information

    @client_reference_information.setter
    def client_reference_information(self, client_reference_information):
        """
        Sets the client_reference_information of this VerifyCustomerAddressRequest.

        :param client_reference_information: The client_reference_information of this VerifyCustomerAddressRequest.
        :type: Riskv1addressverificationsClientReferenceInformation
        """

        self._client_reference_information = client_reference_information

    @property
    def order_information(self):
        """
        Gets the order_information of this VerifyCustomerAddressRequest.

        :return: The order_information of this VerifyCustomerAddressRequest.
        :rtype: Riskv1addressverificationsOrderInformation
        """
        return self._order_information

    @order_information.setter
    def order_information(self, order_information):
        """
        Sets the order_information of this VerifyCustomerAddressRequest.

        :param order_information: The order_information of this VerifyCustomerAddressRequest.
        :type: Riskv1addressverificationsOrderInformation
        """

        self._order_information = order_information

    @property
    def buyer_information(self):
        """
        Gets the buyer_information of this VerifyCustomerAddressRequest.

        :return: The buyer_information of this VerifyCustomerAddressRequest.
        :rtype: Riskv1addressverificationsBuyerInformation
        """
        return self._buyer_information

    @buyer_information.setter
    def buyer_information(self, buyer_information):
        """
        Sets the buyer_information of this VerifyCustomerAddressRequest.

        :param buyer_information: The buyer_information of this VerifyCustomerAddressRequest.
        :type: Riskv1addressverificationsBuyerInformation
        """

        self._buyer_information = buyer_information

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, VerifyCustomerAddressRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
