# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class PtsV2PaymentsPost201ResponseClientReferenceInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'code': 'str',
        'submit_local_date_time': 'str',
        'owner_merchant_id': 'str'
    }

    attribute_map = {
        'code': 'code',
        'submit_local_date_time': 'submitLocalDateTime',
        'owner_merchant_id': 'ownerMerchantId'
    }

    def __init__(self, code=None, submit_local_date_time=None, owner_merchant_id=None):
        """
        PtsV2PaymentsPost201ResponseClientReferenceInformation - a model defined in Swagger
        """

        self._code = None
        self._submit_local_date_time = None
        self._owner_merchant_id = None

        if code is not None:
          self.code = code
        if submit_local_date_time is not None:
          self.submit_local_date_time = submit_local_date_time
        if owner_merchant_id is not None:
          self.owner_merchant_id = owner_merchant_id

    @property
    def code(self):
        """
        Gets the code of this PtsV2PaymentsPost201ResponseClientReferenceInformation.
        Merchant-generated order reference or tracking number. It is recommended that you send a unique value for each transaction so that you can perform meaningful searches for the transaction.  #### Used by **Authorization** Required field.  #### PIN Debit Requests for PIN debit reversals need to use the same merchant reference number that was used in the transaction that is being reversed.  Required field for all PIN Debit requests (purchase, credit, and reversal).  #### FDC Nashville Global Certain circumstances can cause the processor to truncate this value to 15 or 17 characters for Level II and Level III processing, which can cause a discrepancy between the value you submit and the value included in some processor reports. 

        :return: The code of this PtsV2PaymentsPost201ResponseClientReferenceInformation.
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """
        Sets the code of this PtsV2PaymentsPost201ResponseClientReferenceInformation.
        Merchant-generated order reference or tracking number. It is recommended that you send a unique value for each transaction so that you can perform meaningful searches for the transaction.  #### Used by **Authorization** Required field.  #### PIN Debit Requests for PIN debit reversals need to use the same merchant reference number that was used in the transaction that is being reversed.  Required field for all PIN Debit requests (purchase, credit, and reversal).  #### FDC Nashville Global Certain circumstances can cause the processor to truncate this value to 15 or 17 characters for Level II and Level III processing, which can cause a discrepancy between the value you submit and the value included in some processor reports. 

        :param code: The code of this PtsV2PaymentsPost201ResponseClientReferenceInformation.
        :type: str
        """
        if code is not None and len(code) > 50:
            raise ValueError("Invalid value for `code`, length must be less than or equal to `50`")

        self._code = code

    @property
    def submit_local_date_time(self):
        """
        Gets the submit_local_date_time of this PtsV2PaymentsPost201ResponseClientReferenceInformation.
        Date and time at your physical location.  Format: `YYYYMMDDhhmmss`, where YYYY = year, MM = month, DD = day, hh = hour, mm = minutes ss = seconds  #### PIN Debit Optional field for PIN Debit purchase and credit requests. 

        :return: The submit_local_date_time of this PtsV2PaymentsPost201ResponseClientReferenceInformation.
        :rtype: str
        """
        return self._submit_local_date_time

    @submit_local_date_time.setter
    def submit_local_date_time(self, submit_local_date_time):
        """
        Sets the submit_local_date_time of this PtsV2PaymentsPost201ResponseClientReferenceInformation.
        Date and time at your physical location.  Format: `YYYYMMDDhhmmss`, where YYYY = year, MM = month, DD = day, hh = hour, mm = minutes ss = seconds  #### PIN Debit Optional field for PIN Debit purchase and credit requests. 

        :param submit_local_date_time: The submit_local_date_time of this PtsV2PaymentsPost201ResponseClientReferenceInformation.
        :type: str
        """
        if submit_local_date_time is not None and len(submit_local_date_time) > 14:
            raise ValueError("Invalid value for `submit_local_date_time`, length must be less than or equal to `14`")

        self._submit_local_date_time = submit_local_date_time

    @property
    def owner_merchant_id(self):
        """
        Gets the owner_merchant_id of this PtsV2PaymentsPost201ResponseClientReferenceInformation.
        Merchant ID that was used to create the subscription or customer profile for which the service was requested.  If your CyberSource account is enabled for Recurring Billing, this field is returned only if you are using subscription sharing and if your merchant ID is in the same merchant ID pool as the owner merchant ID.  If your CyberSource account is enabled for Payment Tokenization, this field is returned only if you are using profile sharing and if your merchant ID is in the same merchant ID pool as the owner merchant ID. 

        :return: The owner_merchant_id of this PtsV2PaymentsPost201ResponseClientReferenceInformation.
        :rtype: str
        """
        return self._owner_merchant_id

    @owner_merchant_id.setter
    def owner_merchant_id(self, owner_merchant_id):
        """
        Sets the owner_merchant_id of this PtsV2PaymentsPost201ResponseClientReferenceInformation.
        Merchant ID that was used to create the subscription or customer profile for which the service was requested.  If your CyberSource account is enabled for Recurring Billing, this field is returned only if you are using subscription sharing and if your merchant ID is in the same merchant ID pool as the owner merchant ID.  If your CyberSource account is enabled for Payment Tokenization, this field is returned only if you are using profile sharing and if your merchant ID is in the same merchant ID pool as the owner merchant ID. 

        :param owner_merchant_id: The owner_merchant_id of this PtsV2PaymentsPost201ResponseClientReferenceInformation.
        :type: str
        """

        self._owner_merchant_id = owner_merchant_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, PtsV2PaymentsPost201ResponseClientReferenceInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
