# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class PtsV2PaymentsPost201ResponseProcessorInformationRouting(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'network': 'str',
        'network_name': 'str',
        'customer_signature_required': 'str'
    }

    attribute_map = {
        'network': 'network',
        'network_name': 'networkName',
        'customer_signature_required': 'customerSignatureRequired'
    }

    def __init__(self, network=None, network_name=None, customer_signature_required=None):
        """
        PtsV2PaymentsPost201ResponseProcessorInformationRouting - a model defined in Swagger
        """

        self._network = None
        self._network_name = None
        self._customer_signature_required = None

        if network is not None:
          self.network = network
        if network_name is not None:
          self.network_name = network_name
        if customer_signature_required is not None:
          self.customer_signature_required = customer_signature_required

    @property
    def network(self):
        """
        Gets the network of this PtsV2PaymentsPost201ResponseProcessorInformationRouting.
        Indicates whether the transaction was routed on a credit network, a debit network, or the STAR signature debit network.  Possible values: - `C`: Credit network - `D`: Debit network (without signature) - `S`: STAR signature debit network  This field is supported only on FDC Nashville Global.  #### PIN debit Network that was used to route the transaction. This is the list of network codes:  | Network | Code | | --- | --- | | Accel | E | | AFFN | U | | Alaska Option | 3 | | CU24 | C | | Interlink | G | | Maestro | 8 | | NETS | P | | NYCE | F | | Pulse | H | | Shazam | 7 | | Star | M | | Visa | V |  Returned by PIN debit credit and PIN debit purchase. 

        :return: The network of this PtsV2PaymentsPost201ResponseProcessorInformationRouting.
        :rtype: str
        """
        return self._network

    @network.setter
    def network(self, network):
        """
        Sets the network of this PtsV2PaymentsPost201ResponseProcessorInformationRouting.
        Indicates whether the transaction was routed on a credit network, a debit network, or the STAR signature debit network.  Possible values: - `C`: Credit network - `D`: Debit network (without signature) - `S`: STAR signature debit network  This field is supported only on FDC Nashville Global.  #### PIN debit Network that was used to route the transaction. This is the list of network codes:  | Network | Code | | --- | --- | | Accel | E | | AFFN | U | | Alaska Option | 3 | | CU24 | C | | Interlink | G | | Maestro | 8 | | NETS | P | | NYCE | F | | Pulse | H | | Shazam | 7 | | Star | M | | Visa | V |  Returned by PIN debit credit and PIN debit purchase. 

        :param network: The network of this PtsV2PaymentsPost201ResponseProcessorInformationRouting.
        :type: str
        """
        if network is not None and len(network) > 1:
            raise ValueError("Invalid value for `network`, length must be less than or equal to `1`")

        self._network = network

    @property
    def network_name(self):
        """
        Gets the network_name of this PtsV2PaymentsPost201ResponseProcessorInformationRouting.
        Name of the network on which the transaction was routed.  This reply field is supported only on FDC Nashville Global. 

        :return: The network_name of this PtsV2PaymentsPost201ResponseProcessorInformationRouting.
        :rtype: str
        """
        return self._network_name

    @network_name.setter
    def network_name(self, network_name):
        """
        Sets the network_name of this PtsV2PaymentsPost201ResponseProcessorInformationRouting.
        Name of the network on which the transaction was routed.  This reply field is supported only on FDC Nashville Global. 

        :param network_name: The network_name of this PtsV2PaymentsPost201ResponseProcessorInformationRouting.
        :type: str
        """
        if network_name is not None and len(network_name) > 10:
            raise ValueError("Invalid value for `network_name`, length must be less than or equal to `10`")

        self._network_name = network_name

    @property
    def customer_signature_required(self):
        """
        Gets the customer_signature_required of this PtsV2PaymentsPost201ResponseProcessorInformationRouting.
        Indicates whether you need to obtain the cardholder's signature.  Possible values: - `Y`: You need to obtain the cardholder's signature. - `N`: You do not need to obtain the cardholder's signature.  This field is supported only on FDC Nashville Global. 

        :return: The customer_signature_required of this PtsV2PaymentsPost201ResponseProcessorInformationRouting.
        :rtype: str
        """
        return self._customer_signature_required

    @customer_signature_required.setter
    def customer_signature_required(self, customer_signature_required):
        """
        Sets the customer_signature_required of this PtsV2PaymentsPost201ResponseProcessorInformationRouting.
        Indicates whether you need to obtain the cardholder's signature.  Possible values: - `Y`: You need to obtain the cardholder's signature. - `N`: You do not need to obtain the cardholder's signature.  This field is supported only on FDC Nashville Global. 

        :param customer_signature_required: The customer_signature_required of this PtsV2PaymentsPost201ResponseProcessorInformationRouting.
        :type: str
        """
        if customer_signature_required is not None and len(customer_signature_required) > 1:
            raise ValueError("Invalid value for `customer_signature_required`, length must be less than or equal to `1`")

        self._customer_signature_required = customer_signature_required

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, PtsV2PaymentsPost201ResponseProcessorInformationRouting):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
