# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class PtsV2PayoutsPost201Response(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'links': 'PtsV2IncrementalAuthorizationPatch201ResponseLinks',
        'id': 'str',
        'submit_time_utc': 'str',
        'status': 'str',
        'reconciliation_id': 'str',
        'error_information': 'PtsV2PayoutsPost201ResponseErrorInformation',
        'client_reference_information': 'PtsV2PaymentsPost201ResponseClientReferenceInformation',
        'merchant_information': 'PtsV2PayoutsPost201ResponseMerchantInformation',
        'order_information': 'PtsV2PayoutsPost201ResponseOrderInformation',
        'processor_information': 'PtsV2PayoutsPost201ResponseProcessorInformation',
        'recipient_information': 'PtsV2PayoutsPost201ResponseRecipientInformation'
    }

    attribute_map = {
        'links': '_links',
        'id': 'id',
        'submit_time_utc': 'submitTimeUtc',
        'status': 'status',
        'reconciliation_id': 'reconciliationId',
        'error_information': 'errorInformation',
        'client_reference_information': 'clientReferenceInformation',
        'merchant_information': 'merchantInformation',
        'order_information': 'orderInformation',
        'processor_information': 'processorInformation',
        'recipient_information': 'recipientInformation'
    }

    def __init__(self, links=None, id=None, submit_time_utc=None, status=None, reconciliation_id=None, error_information=None, client_reference_information=None, merchant_information=None, order_information=None, processor_information=None, recipient_information=None):
        """
        PtsV2PayoutsPost201Response - a model defined in Swagger
        """

        self._links = None
        self._id = None
        self._submit_time_utc = None
        self._status = None
        self._reconciliation_id = None
        self._error_information = None
        self._client_reference_information = None
        self._merchant_information = None
        self._order_information = None
        self._processor_information = None
        self._recipient_information = None

        if links is not None:
          self.links = links
        if id is not None:
          self.id = id
        if submit_time_utc is not None:
          self.submit_time_utc = submit_time_utc
        if status is not None:
          self.status = status
        if reconciliation_id is not None:
          self.reconciliation_id = reconciliation_id
        if error_information is not None:
          self.error_information = error_information
        if client_reference_information is not None:
          self.client_reference_information = client_reference_information
        if merchant_information is not None:
          self.merchant_information = merchant_information
        if order_information is not None:
          self.order_information = order_information
        if processor_information is not None:
          self.processor_information = processor_information
        if recipient_information is not None:
          self.recipient_information = recipient_information

    @property
    def links(self):
        """
        Gets the links of this PtsV2PayoutsPost201Response.

        :return: The links of this PtsV2PayoutsPost201Response.
        :rtype: PtsV2IncrementalAuthorizationPatch201ResponseLinks
        """
        return self._links

    @links.setter
    def links(self, links):
        """
        Sets the links of this PtsV2PayoutsPost201Response.

        :param links: The links of this PtsV2PayoutsPost201Response.
        :type: PtsV2IncrementalAuthorizationPatch201ResponseLinks
        """

        self._links = links

    @property
    def id(self):
        """
        Gets the id of this PtsV2PayoutsPost201Response.
        An unique identification number to identify the submitted request. It is also appended to the endpoint of the resource.  On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.  #### PIN debit Returned for all PIN debit services. 

        :return: The id of this PtsV2PayoutsPost201Response.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this PtsV2PayoutsPost201Response.
        An unique identification number to identify the submitted request. It is also appended to the endpoint of the resource.  On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.  #### PIN debit Returned for all PIN debit services. 

        :param id: The id of this PtsV2PayoutsPost201Response.
        :type: str
        """
        if id is not None and len(id) > 26:
            raise ValueError("Invalid value for `id`, length must be less than or equal to `26`")

        self._id = id

    @property
    def submit_time_utc(self):
        """
        Gets the submit_time_utc of this PtsV2PayoutsPost201Response.
        Time of request in UTC. `Format: YYYY-MM-DDThh:mm:ssZ`  Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57 (10:47:57 p.m.). The T separates the date and the time. The Z indicates UTC. 

        :return: The submit_time_utc of this PtsV2PayoutsPost201Response.
        :rtype: str
        """
        return self._submit_time_utc

    @submit_time_utc.setter
    def submit_time_utc(self, submit_time_utc):
        """
        Sets the submit_time_utc of this PtsV2PayoutsPost201Response.
        Time of request in UTC. `Format: YYYY-MM-DDThh:mm:ssZ`  Example 2016-08-11T22:47:57Z equals August 11, 2016, at 22:47:57 (10:47:57 p.m.). The T separates the date and the time. The Z indicates UTC. 

        :param submit_time_utc: The submit_time_utc of this PtsV2PayoutsPost201Response.
        :type: str
        """

        self._submit_time_utc = submit_time_utc

    @property
    def status(self):
        """
        Gets the status of this PtsV2PayoutsPost201Response.
        The status of the submitted transaction.  Possible values:  - ACCEPTED  - DECLINED  - INVALID_REQUEST 

        :return: The status of this PtsV2PayoutsPost201Response.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this PtsV2PayoutsPost201Response.
        The status of the submitted transaction.  Possible values:  - ACCEPTED  - DECLINED  - INVALID_REQUEST 

        :param status: The status of this PtsV2PayoutsPost201Response.
        :type: str
        """

        self._status = status

    @property
    def reconciliation_id(self):
        """
        Gets the reconciliation_id of this PtsV2PayoutsPost201Response.
        Cybersource or merchant generated transaction reference number. This is sent to the processor and is echoed back in the response to the merchant. This is This value is used for reconciliation purposes. 

        :return: The reconciliation_id of this PtsV2PayoutsPost201Response.
        :rtype: str
        """
        return self._reconciliation_id

    @reconciliation_id.setter
    def reconciliation_id(self, reconciliation_id):
        """
        Sets the reconciliation_id of this PtsV2PayoutsPost201Response.
        Cybersource or merchant generated transaction reference number. This is sent to the processor and is echoed back in the response to the merchant. This is This value is used for reconciliation purposes. 

        :param reconciliation_id: The reconciliation_id of this PtsV2PayoutsPost201Response.
        :type: str
        """
        if reconciliation_id is not None and len(reconciliation_id) > 25:
            raise ValueError("Invalid value for `reconciliation_id`, length must be less than or equal to `25`")

        self._reconciliation_id = reconciliation_id

    @property
    def error_information(self):
        """
        Gets the error_information of this PtsV2PayoutsPost201Response.

        :return: The error_information of this PtsV2PayoutsPost201Response.
        :rtype: PtsV2PayoutsPost201ResponseErrorInformation
        """
        return self._error_information

    @error_information.setter
    def error_information(self, error_information):
        """
        Sets the error_information of this PtsV2PayoutsPost201Response.

        :param error_information: The error_information of this PtsV2PayoutsPost201Response.
        :type: PtsV2PayoutsPost201ResponseErrorInformation
        """

        self._error_information = error_information

    @property
    def client_reference_information(self):
        """
        Gets the client_reference_information of this PtsV2PayoutsPost201Response.

        :return: The client_reference_information of this PtsV2PayoutsPost201Response.
        :rtype: PtsV2PaymentsPost201ResponseClientReferenceInformation
        """
        return self._client_reference_information

    @client_reference_information.setter
    def client_reference_information(self, client_reference_information):
        """
        Sets the client_reference_information of this PtsV2PayoutsPost201Response.

        :param client_reference_information: The client_reference_information of this PtsV2PayoutsPost201Response.
        :type: PtsV2PaymentsPost201ResponseClientReferenceInformation
        """

        self._client_reference_information = client_reference_information

    @property
    def merchant_information(self):
        """
        Gets the merchant_information of this PtsV2PayoutsPost201Response.

        :return: The merchant_information of this PtsV2PayoutsPost201Response.
        :rtype: PtsV2PayoutsPost201ResponseMerchantInformation
        """
        return self._merchant_information

    @merchant_information.setter
    def merchant_information(self, merchant_information):
        """
        Sets the merchant_information of this PtsV2PayoutsPost201Response.

        :param merchant_information: The merchant_information of this PtsV2PayoutsPost201Response.
        :type: PtsV2PayoutsPost201ResponseMerchantInformation
        """

        self._merchant_information = merchant_information

    @property
    def order_information(self):
        """
        Gets the order_information of this PtsV2PayoutsPost201Response.

        :return: The order_information of this PtsV2PayoutsPost201Response.
        :rtype: PtsV2PayoutsPost201ResponseOrderInformation
        """
        return self._order_information

    @order_information.setter
    def order_information(self, order_information):
        """
        Sets the order_information of this PtsV2PayoutsPost201Response.

        :param order_information: The order_information of this PtsV2PayoutsPost201Response.
        :type: PtsV2PayoutsPost201ResponseOrderInformation
        """

        self._order_information = order_information

    @property
    def processor_information(self):
        """
        Gets the processor_information of this PtsV2PayoutsPost201Response.

        :return: The processor_information of this PtsV2PayoutsPost201Response.
        :rtype: PtsV2PayoutsPost201ResponseProcessorInformation
        """
        return self._processor_information

    @processor_information.setter
    def processor_information(self, processor_information):
        """
        Sets the processor_information of this PtsV2PayoutsPost201Response.

        :param processor_information: The processor_information of this PtsV2PayoutsPost201Response.
        :type: PtsV2PayoutsPost201ResponseProcessorInformation
        """

        self._processor_information = processor_information

    @property
    def recipient_information(self):
        """
        Gets the recipient_information of this PtsV2PayoutsPost201Response.

        :return: The recipient_information of this PtsV2PayoutsPost201Response.
        :rtype: PtsV2PayoutsPost201ResponseRecipientInformation
        """
        return self._recipient_information

    @recipient_information.setter
    def recipient_information(self, recipient_information):
        """
        Sets the recipient_information of this PtsV2PayoutsPost201Response.

        :param recipient_information: The recipient_information of this PtsV2PayoutsPost201Response.
        :type: PtsV2PayoutsPost201ResponseRecipientInformation
        """

        self._recipient_information = recipient_information

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, PtsV2PayoutsPost201Response):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
