# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Riskv1authenticationsOrderInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'amount_details': 'Riskv1authenticationsOrderInformationAmountDetails',
        'pre_order': 'str',
        'pre_order_date': 'str',
        'reordered': 'bool',
        'ship_to': 'Riskv1decisionsOrderInformationShipTo',
        'line_items': 'list[Riskv1authenticationsOrderInformationLineItems]',
        'bill_to': 'Riskv1authenticationsOrderInformationBillTo',
        'total_offers_count': 'str'
    }

    attribute_map = {
        'amount_details': 'amountDetails',
        'pre_order': 'preOrder',
        'pre_order_date': 'preOrderDate',
        'reordered': 'reordered',
        'ship_to': 'shipTo',
        'line_items': 'lineItems',
        'bill_to': 'billTo',
        'total_offers_count': 'totalOffersCount'
    }

    def __init__(self, amount_details=None, pre_order=None, pre_order_date=None, reordered=None, ship_to=None, line_items=None, bill_to=None, total_offers_count=None):
        """
        Riskv1authenticationsOrderInformation - a model defined in Swagger
        """

        self._amount_details = None
        self._pre_order = None
        self._pre_order_date = None
        self._reordered = None
        self._ship_to = None
        self._line_items = None
        self._bill_to = None
        self._total_offers_count = None

        if amount_details is not None:
          self.amount_details = amount_details
        if pre_order is not None:
          self.pre_order = pre_order
        if pre_order_date is not None:
          self.pre_order_date = pre_order_date
        if reordered is not None:
          self.reordered = reordered
        if ship_to is not None:
          self.ship_to = ship_to
        if line_items is not None:
          self.line_items = line_items
        if bill_to is not None:
          self.bill_to = bill_to
        if total_offers_count is not None:
          self.total_offers_count = total_offers_count

    @property
    def amount_details(self):
        """
        Gets the amount_details of this Riskv1authenticationsOrderInformation.

        :return: The amount_details of this Riskv1authenticationsOrderInformation.
        :rtype: Riskv1authenticationsOrderInformationAmountDetails
        """
        return self._amount_details

    @amount_details.setter
    def amount_details(self, amount_details):
        """
        Sets the amount_details of this Riskv1authenticationsOrderInformation.

        :param amount_details: The amount_details of this Riskv1authenticationsOrderInformation.
        :type: Riskv1authenticationsOrderInformationAmountDetails
        """

        self._amount_details = amount_details

    @property
    def pre_order(self):
        """
        Gets the pre_order of this Riskv1authenticationsOrderInformation.
        Indicates whether cardholder is placing an order with a future availability or release date. This field can contain one of these values: - MERCHANDISE_AVAILABLE: Merchandise available - FUTURE_AVAILABILITY: Future availability 

        :return: The pre_order of this Riskv1authenticationsOrderInformation.
        :rtype: str
        """
        return self._pre_order

    @pre_order.setter
    def pre_order(self, pre_order):
        """
        Sets the pre_order of this Riskv1authenticationsOrderInformation.
        Indicates whether cardholder is placing an order with a future availability or release date. This field can contain one of these values: - MERCHANDISE_AVAILABLE: Merchandise available - FUTURE_AVAILABILITY: Future availability 

        :param pre_order: The pre_order of this Riskv1authenticationsOrderInformation.
        :type: str
        """

        self._pre_order = pre_order

    @property
    def pre_order_date(self):
        """
        Gets the pre_order_date of this Riskv1authenticationsOrderInformation.
        Expected date that a pre-ordered purchase will be available. Format: YYYYMMDD 

        :return: The pre_order_date of this Riskv1authenticationsOrderInformation.
        :rtype: str
        """
        return self._pre_order_date

    @pre_order_date.setter
    def pre_order_date(self, pre_order_date):
        """
        Sets the pre_order_date of this Riskv1authenticationsOrderInformation.
        Expected date that a pre-ordered purchase will be available. Format: YYYYMMDD 

        :param pre_order_date: The pre_order_date of this Riskv1authenticationsOrderInformation.
        :type: str
        """
        if pre_order_date is not None and len(pre_order_date) > 10:
            raise ValueError("Invalid value for `pre_order_date`, length must be less than or equal to `10`")

        self._pre_order_date = pre_order_date

    @property
    def reordered(self):
        """
        Gets the reordered of this Riskv1authenticationsOrderInformation.
        Indicates whether the cardholder is reordering previously purchased merchandise. This field can contain one of these values: - false: First time ordered - true: Reordered 

        :return: The reordered of this Riskv1authenticationsOrderInformation.
        :rtype: bool
        """
        return self._reordered

    @reordered.setter
    def reordered(self, reordered):
        """
        Sets the reordered of this Riskv1authenticationsOrderInformation.
        Indicates whether the cardholder is reordering previously purchased merchandise. This field can contain one of these values: - false: First time ordered - true: Reordered 

        :param reordered: The reordered of this Riskv1authenticationsOrderInformation.
        :type: bool
        """

        self._reordered = reordered

    @property
    def ship_to(self):
        """
        Gets the ship_to of this Riskv1authenticationsOrderInformation.

        :return: The ship_to of this Riskv1authenticationsOrderInformation.
        :rtype: Riskv1decisionsOrderInformationShipTo
        """
        return self._ship_to

    @ship_to.setter
    def ship_to(self, ship_to):
        """
        Sets the ship_to of this Riskv1authenticationsOrderInformation.

        :param ship_to: The ship_to of this Riskv1authenticationsOrderInformation.
        :type: Riskv1decisionsOrderInformationShipTo
        """

        self._ship_to = ship_to

    @property
    def line_items(self):
        """
        Gets the line_items of this Riskv1authenticationsOrderInformation.
        This array contains detailed information about individual products in the order.

        :return: The line_items of this Riskv1authenticationsOrderInformation.
        :rtype: list[Riskv1authenticationsOrderInformationLineItems]
        """
        return self._line_items

    @line_items.setter
    def line_items(self, line_items):
        """
        Sets the line_items of this Riskv1authenticationsOrderInformation.
        This array contains detailed information about individual products in the order.

        :param line_items: The line_items of this Riskv1authenticationsOrderInformation.
        :type: list[Riskv1authenticationsOrderInformationLineItems]
        """

        self._line_items = line_items

    @property
    def bill_to(self):
        """
        Gets the bill_to of this Riskv1authenticationsOrderInformation.

        :return: The bill_to of this Riskv1authenticationsOrderInformation.
        :rtype: Riskv1authenticationsOrderInformationBillTo
        """
        return self._bill_to

    @bill_to.setter
    def bill_to(self, bill_to):
        """
        Sets the bill_to of this Riskv1authenticationsOrderInformation.

        :param bill_to: The bill_to of this Riskv1authenticationsOrderInformation.
        :type: Riskv1authenticationsOrderInformationBillTo
        """

        self._bill_to = bill_to

    @property
    def total_offers_count(self):
        """
        Gets the total_offers_count of this Riskv1authenticationsOrderInformation.
        Total number of articles/items in the order as a numeric decimal count. Possible values: 00 - 99 

        :return: The total_offers_count of this Riskv1authenticationsOrderInformation.
        :rtype: str
        """
        return self._total_offers_count

    @total_offers_count.setter
    def total_offers_count(self, total_offers_count):
        """
        Sets the total_offers_count of this Riskv1authenticationsOrderInformation.
        Total number of articles/items in the order as a numeric decimal count. Possible values: 00 - 99 

        :param total_offers_count: The total_offers_count of this Riskv1authenticationsOrderInformation.
        :type: str
        """
        if total_offers_count is not None and len(total_offers_count) > 2:
            raise ValueError("Invalid value for `total_offers_count`, length must be less than or equal to `2`")

        self._total_offers_count = total_offers_count

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Riskv1authenticationsOrderInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
