# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class ReportingV3PurchaseRefundDetailsGet200Response(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'offset': 'int',
        'limit': 'int',
        'page_results': 'int',
        'request_details': 'list[ReportingV3PurchaseRefundDetailsGet200ResponseRequestDetails]',
        'settlements': 'list[ReportingV3PurchaseRefundDetailsGet200ResponseSettlements]',
        'authorizations': 'list[ReportingV3PurchaseRefundDetailsGet200ResponseAuthorizations]',
        'fee_and_funding_details': 'list[ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails]',
        'others': 'list[ReportingV3PurchaseRefundDetailsGet200ResponseOthers]',
        'settlement_statuses': 'list[ReportingV3PurchaseRefundDetailsGet200ResponseSettlementStatuses]'
    }

    attribute_map = {
        'offset': 'offset',
        'limit': 'limit',
        'page_results': 'pageResults',
        'request_details': 'requestDetails',
        'settlements': 'settlements',
        'authorizations': 'authorizations',
        'fee_and_funding_details': 'feeAndFundingDetails',
        'others': 'others',
        'settlement_statuses': 'settlementStatuses'
    }

    def __init__(self, offset=None, limit=None, page_results=None, request_details=None, settlements=None, authorizations=None, fee_and_funding_details=None, others=None, settlement_statuses=None):
        """
        ReportingV3PurchaseRefundDetailsGet200Response - a model defined in Swagger
        """

        self._offset = None
        self._limit = None
        self._page_results = None
        self._request_details = None
        self._settlements = None
        self._authorizations = None
        self._fee_and_funding_details = None
        self._others = None
        self._settlement_statuses = None

        if offset is not None:
          self.offset = offset
        if limit is not None:
          self.limit = limit
        if page_results is not None:
          self.page_results = page_results
        if request_details is not None:
          self.request_details = request_details
        if settlements is not None:
          self.settlements = settlements
        if authorizations is not None:
          self.authorizations = authorizations
        if fee_and_funding_details is not None:
          self.fee_and_funding_details = fee_and_funding_details
        if others is not None:
          self.others = others
        if settlement_statuses is not None:
          self.settlement_statuses = settlement_statuses

    @property
    def offset(self):
        """
        Gets the offset of this ReportingV3PurchaseRefundDetailsGet200Response.

        :return: The offset of this ReportingV3PurchaseRefundDetailsGet200Response.
        :rtype: int
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """
        Sets the offset of this ReportingV3PurchaseRefundDetailsGet200Response.

        :param offset: The offset of this ReportingV3PurchaseRefundDetailsGet200Response.
        :type: int
        """

        self._offset = offset

    @property
    def limit(self):
        """
        Gets the limit of this ReportingV3PurchaseRefundDetailsGet200Response.

        :return: The limit of this ReportingV3PurchaseRefundDetailsGet200Response.
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """
        Sets the limit of this ReportingV3PurchaseRefundDetailsGet200Response.

        :param limit: The limit of this ReportingV3PurchaseRefundDetailsGet200Response.
        :type: int
        """

        self._limit = limit

    @property
    def page_results(self):
        """
        Gets the page_results of this ReportingV3PurchaseRefundDetailsGet200Response.

        :return: The page_results of this ReportingV3PurchaseRefundDetailsGet200Response.
        :rtype: int
        """
        return self._page_results

    @page_results.setter
    def page_results(self, page_results):
        """
        Sets the page_results of this ReportingV3PurchaseRefundDetailsGet200Response.

        :param page_results: The page_results of this ReportingV3PurchaseRefundDetailsGet200Response.
        :type: int
        """

        self._page_results = page_results

    @property
    def request_details(self):
        """
        Gets the request_details of this ReportingV3PurchaseRefundDetailsGet200Response.
        List of Request Info values

        :return: The request_details of this ReportingV3PurchaseRefundDetailsGet200Response.
        :rtype: list[ReportingV3PurchaseRefundDetailsGet200ResponseRequestDetails]
        """
        return self._request_details

    @request_details.setter
    def request_details(self, request_details):
        """
        Sets the request_details of this ReportingV3PurchaseRefundDetailsGet200Response.
        List of Request Info values

        :param request_details: The request_details of this ReportingV3PurchaseRefundDetailsGet200Response.
        :type: list[ReportingV3PurchaseRefundDetailsGet200ResponseRequestDetails]
        """

        self._request_details = request_details

    @property
    def settlements(self):
        """
        Gets the settlements of this ReportingV3PurchaseRefundDetailsGet200Response.
        List of Settlement Info values

        :return: The settlements of this ReportingV3PurchaseRefundDetailsGet200Response.
        :rtype: list[ReportingV3PurchaseRefundDetailsGet200ResponseSettlements]
        """
        return self._settlements

    @settlements.setter
    def settlements(self, settlements):
        """
        Sets the settlements of this ReportingV3PurchaseRefundDetailsGet200Response.
        List of Settlement Info values

        :param settlements: The settlements of this ReportingV3PurchaseRefundDetailsGet200Response.
        :type: list[ReportingV3PurchaseRefundDetailsGet200ResponseSettlements]
        """

        self._settlements = settlements

    @property
    def authorizations(self):
        """
        Gets the authorizations of this ReportingV3PurchaseRefundDetailsGet200Response.
        List of Authorization Info values

        :return: The authorizations of this ReportingV3PurchaseRefundDetailsGet200Response.
        :rtype: list[ReportingV3PurchaseRefundDetailsGet200ResponseAuthorizations]
        """
        return self._authorizations

    @authorizations.setter
    def authorizations(self, authorizations):
        """
        Sets the authorizations of this ReportingV3PurchaseRefundDetailsGet200Response.
        List of Authorization Info values

        :param authorizations: The authorizations of this ReportingV3PurchaseRefundDetailsGet200Response.
        :type: list[ReportingV3PurchaseRefundDetailsGet200ResponseAuthorizations]
        """

        self._authorizations = authorizations

    @property
    def fee_and_funding_details(self):
        """
        Gets the fee_and_funding_details of this ReportingV3PurchaseRefundDetailsGet200Response.
        List of Fee Funding Info values

        :return: The fee_and_funding_details of this ReportingV3PurchaseRefundDetailsGet200Response.
        :rtype: list[ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails]
        """
        return self._fee_and_funding_details

    @fee_and_funding_details.setter
    def fee_and_funding_details(self, fee_and_funding_details):
        """
        Sets the fee_and_funding_details of this ReportingV3PurchaseRefundDetailsGet200Response.
        List of Fee Funding Info values

        :param fee_and_funding_details: The fee_and_funding_details of this ReportingV3PurchaseRefundDetailsGet200Response.
        :type: list[ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails]
        """

        self._fee_and_funding_details = fee_and_funding_details

    @property
    def others(self):
        """
        Gets the others of this ReportingV3PurchaseRefundDetailsGet200Response.
        List of Other Info values

        :return: The others of this ReportingV3PurchaseRefundDetailsGet200Response.
        :rtype: list[ReportingV3PurchaseRefundDetailsGet200ResponseOthers]
        """
        return self._others

    @others.setter
    def others(self, others):
        """
        Sets the others of this ReportingV3PurchaseRefundDetailsGet200Response.
        List of Other Info values

        :param others: The others of this ReportingV3PurchaseRefundDetailsGet200Response.
        :type: list[ReportingV3PurchaseRefundDetailsGet200ResponseOthers]
        """

        self._others = others

    @property
    def settlement_statuses(self):
        """
        Gets the settlement_statuses of this ReportingV3PurchaseRefundDetailsGet200Response.
        List of Settlement Status Info values

        :return: The settlement_statuses of this ReportingV3PurchaseRefundDetailsGet200Response.
        :rtype: list[ReportingV3PurchaseRefundDetailsGet200ResponseSettlementStatuses]
        """
        return self._settlement_statuses

    @settlement_statuses.setter
    def settlement_statuses(self, settlement_statuses):
        """
        Sets the settlement_statuses of this ReportingV3PurchaseRefundDetailsGet200Response.
        List of Settlement Status Info values

        :param settlement_statuses: The settlement_statuses of this ReportingV3PurchaseRefundDetailsGet200Response.
        :type: list[ReportingV3PurchaseRefundDetailsGet200ResponseSettlementStatuses]
        """

        self._settlement_statuses = settlement_statuses

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ReportingV3PurchaseRefundDetailsGet200Response):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
