# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class PtsV2PaymentsPost201ResponseRiskInformationVelocity(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'morphing': 'list[PtsV2PaymentsPost201ResponseRiskInformationVelocityMorphing]',
        'address': 'list[str]'
    }

    attribute_map = {
        'morphing': 'morphing',
        'address': 'address'
    }

    def __init__(self, morphing=None, address=None):
        """
        PtsV2PaymentsPost201ResponseRiskInformationVelocity - a model defined in Swagger
        """

        self._morphing = None
        self._address = None

        if morphing is not None:
          self.morphing = morphing
        if address is not None:
          self.address = address

    @property
    def morphing(self):
        """
        Gets the morphing of this PtsV2PaymentsPost201ResponseRiskInformationVelocity.
        List of information codes triggered by the order. These information codes were generated when you created the order and product velocity rules and are returned so that you can associate them with the rules.  Returned by scoring service. 

        :return: The morphing of this PtsV2PaymentsPost201ResponseRiskInformationVelocity.
        :rtype: list[PtsV2PaymentsPost201ResponseRiskInformationVelocityMorphing]
        """
        return self._morphing

    @morphing.setter
    def morphing(self, morphing):
        """
        Sets the morphing of this PtsV2PaymentsPost201ResponseRiskInformationVelocity.
        List of information codes triggered by the order. These information codes were generated when you created the order and product velocity rules and are returned so that you can associate them with the rules.  Returned by scoring service. 

        :param morphing: The morphing of this PtsV2PaymentsPost201ResponseRiskInformationVelocity.
        :type: list[PtsV2PaymentsPost201ResponseRiskInformationVelocityMorphing]
        """

        self._morphing = morphing

    @property
    def address(self):
        """
        Gets the address of this PtsV2PaymentsPost201ResponseRiskInformationVelocity.

        :return: The address of this PtsV2PaymentsPost201ResponseRiskInformationVelocity.
        :rtype: list[str]
        """
        return self._address

    @address.setter
    def address(self, address):
        """
        Sets the address of this PtsV2PaymentsPost201ResponseRiskInformationVelocity.

        :param address: The address of this PtsV2PaymentsPost201ResponseRiskInformationVelocity.
        :type: list[str]
        """

        self._address = address

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, PtsV2PaymentsPost201ResponseRiskInformationVelocity):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
